package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M?T5,1@$!`0````````````(``P`!`````)H$"#0```#,LP```````#0`(``(
M`"@`'``;``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0(R*X`
M`,BN```%`````!````$`````L````#`%"``P!0B(`@``X!(```8`````$```
M`@```!2P```4,`4(%#`%"!`!```0`0``!@````0````$````2`$``$B!!`A(
M@00(1````$0````$````!````%#E=&0,J0``#"D%"`PI!0CL````[`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````8````@````
M!````!0````#````1TY5`&4O:P?%S1$7)[?:U&_.)91O4:P9)0```%`````(
M````"``````0$`0E0`2`J`$``:*&`:A````"3R@$*3BB,D>*A`P(4````%(`
M``````````````````!4````5@```%<```!8````60```%H`````````6P``
M`%T```!>`````````%\```````````````````!@````8P``````````````
M9````&8```!G````:0````````!K````;0``````````````;P```'````!R
M`````````,C5LG%9Z.WLSMY'+:/@^TGJT^\.I]VC:R_%F[;;S>.>Y^]?>X?Y
MG(%K"4/6##J7"T>8!<;%B060#13BGB'_Y`ZR`8MOQ+F<0&M_FGQ_J9R;;L7?
M']EQ6!R[XY)\U&34?*U+X\`R8MOMX:<""F:OS&9[\$IKXD?&`4-%U>Q]08[%
MPN4_+*$B"R#RV],=^J%L8+F-\0X`````````````````````,`,`````````
M````$@```*P``````````````!(```"^`P`````````````2````J0,`````
M````````$@```)P!`````````````!(```#N`P`````````````2````=0(`
M````````````$@````P``````````````"`````;```````````````@````
MKP,`````````````$@```(@!`````````````!(````/!``````````````2
M````:0$`````````````$@```'L!`````````````!(```!+!```````````
M```2````8`,`````````````$@````\#`````````````!(````G`@``````
M```````2````^```````````````$@```!<"`````````````!(```#3`P``
M```````````2````Q0$`````````````$@```(`$`````````````!(````^
M!``````````````2````'`,`````````````$@```!<#`````````````!(`
M``"3`@`````````````2````Y0$`````````````$@```*$!````````````
M`!(````P`@`````````````2````_`,`````````````$@```'($````````
M`````!(````J`0`````````````2````!P0`````````````$@```"\`````
M`````````!(````9!``````````````2````6`$`````````````$@```,,`
M`````````````!(```!2!``````````````2````YP,`````````````$@``
M`#<$`````````````!(```#,`P`````````````2````H@,`````````````
M$@```%4%`````````````!(````\`0`````````````2````)P0`````````
M````$@```%<"`````````````!(```"(`P`````````````2````00,`````
M````````$@```$D"`````````````!(```#:`P`````````````2````C`(`
M````````````$@```*8!`````````````!(```"1`P`````````````2````
MX0,`````````````$@```,4#`````````````!(```#G```````````````2
M````/0``````````````$@```"X$`````````````!(```!J!```````````
M```2````T@``````````````$@```/D!`````````````!(```"``@``````
M```````2````2P$`````````````$@```%P$`````````````!(```"W`P``
M```````````2````=P,`````````````$@````@#`````````````!(````8
M`0`````````````2````/@(`````````````$@```$\``````````````!(`
M``#3`0`````````````2````7@``````````````$@```'D$````````````
M`!(```"*```````````````2````?P,`````````````$@```'(#````````
M`````!(```!S```````````````2````!@$`````````````$@```+(!``!<
ME00(`````!(```#V!```8,H$"`0````1``\`TP4``/"V!`@-"@``$@`-`/\%
M``#@LP0(G0$``!(`#0#P!```/,H$"``````2``X`E`0``*`R!0@$````(0`9
M`,@$``#`L`0(#0```!(`#0!_!0``H,D$"%H````2``T`E`4``"#-!`CJ6P``
M$0`/`)L````\EP0(`````!(```!J!0``>#(%"``````0`!@`;`4``'@R!0@`
M````(``8`(\%``"`,@4(!````!$`&`"3!```H#(%"`0````A`!D`Y@0```#*
M!`@%````$@`-`/(%``#0L`0(Z0$``!(`#0`3!0``@+4$"$`````2``T`D@0`
M`*`R!0@$````$0`9`(T$``!`QP0((`(``!(`#0!#!0``P+4$""`````2``T`
M7@4``'#&!`AL````$@`-`*,$``"(,@4(`````!``\?^O!```X$(%"``````0
M`/'__00```#!!`AJ!0``$@`-`%$#``!DR@0(!````!$`#P!P!0```)H$"```
M```2``T`(04``/"O!`C$````$@`-`#<%``#PL@0([````!(`#0!E`@``+)<$
M"``````2````V00``,"R!`@B````$@`-`)P$``"(,@4(`````!``\?^C!0``
MX,8$"%T````2``T`=P4``$"O!`@_````$@`-`+\%``"$,@4(!````!$`&`">
M`@``I#(%"!,````1`!D`X`4``."U!`@$`0``$@`-`'D%``"LE`0(`````!(`
M"P``;&EB<&5R;"YS;P!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S
M<V5S`%!E<FQ?<WES7W1E<FT`4&5R;%])<W1A=&)U9E]P='(`4&5R;%]S>7-?
M:6YI=#,`4&5R;%])97AI=%]F;&%G<U]P='(`4&5R;%]S879E7V1E<W1R=6-T
M;W)?>`!097)L7TEC;VUP8W9?<'1R`%!E<FQ?871F;W)K7VQO8VL`4&5R;%])
M8W5R<W1A8VMI;F9O7W!T<@!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO
M8V]N=&5X=`!097)L7TEP87)S97)?<'1R`%!E<FQ?879?<VAI9G0`4&5R;%]S
M=E\R<'9?9FQA9W,`4&5R;%])=&]P7V5N=E]P='(`4&5R;%])=&%I;G1E9%]P
M='(`4&5R;%]S=E]S971P=FX`4&5R;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA
M9W,`4&5R;%]):6Y?979A;%]P='(`4&5R;%]);W!?<'1R`%!E<FQ?265V86Q?
M<F]O=%]P='(`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?1W1H<E]K97E?<'1R`%!E<FQ?1V1O
M7W5N9'5M<%]P='(`4&5R;%])<&5R;%]D97-T<G5C=%]L979E;%]P='(`4&5R
M;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=8
M4P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R
M`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?
M;65M;W)Y7W=R87``;&EB<F5S;VQV+G-O+C(`;&EB;G-L+G-O+C$`;&EB9&PN
M<V\N,@!L:6)M+G-O+C8`;&EB8W)Y<'0N<V\N,0!L:6)U=&EL+G-O+C$`;&EB
M<'1H<F5A9"YS;RXP`&]P96XV-`!L<V5E:S8T`')E860`<'1H<F5A9%]G971S
M<&5C:69I8P!?7V5R<FYO7VQO8V%T:6]N`&-L;W-E`&QI8F,N<V\N-@!?24]?
M<W1D:6Y?=7-E9`!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S
M=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`
M<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T
M<G-T<@!R;61I<@!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P
M96YD:7(`7U]X<W1A=#8T`%]?8W1Y<&5?8E]L;V,`9V5T=6ED`')E861L:6YK
M`&5X96-V<`!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7W-P<FEN
M=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I
M;@!?7V5N=FER;VX`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`+W5S<B]L:6(O
M<&5R;#4O0T]210!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI
M8F-?8W-U7V9I;FD`7V9P7VAW`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?
M96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?7V1A=&%?
M<W1A<G0`>'-?:6YI=`!?7VQI8F-?8W-U7VEN:70`;F%M95]L;V%D7VUY7W!A
M<E]P;`!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`<VEZ95]L;V%D7VUY
M7W!A<E]P;`!P87)?;6MT;7!D:7(`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I
M;F1P<F]G`'!A<E]I;FET7V5N=@!'3$E"0U\R+C0`1TQ)0D-?,BXS`$=,24)#
M7S(N,RXR`$=,24)#7S(N,@!'3$E"0U\R+C,N-`!'3$E"0U\R+C`````"````
M`P`#````!``````````#````!0```````P`&``<``````````P````,`!``"
M``(```````,````%``,````#````"```````!0`#``,``P`#``,````#````
M`P`"`````P`#````"0`#``,```````,``P````````````0``P`#``<`````
M``````````,````#``,``````````0`!``$``0`#``$``0`!`````0`!``$`
M`P`!``$``0`#``$``0`!``$``0`!``$``0`!``$````!``$``0`!``$````!
M``$````!``8`1P,``!````!P````%&EI#0``"0`,!@``$````!-I:0T```@`
M%@8``!````!R&6D)```&`"`&```0````$FEI#0``!0`L!@``$````'09:0D`
M``0`-@8``!`````0:6D-```#`$(&`````````0`"`/@"```0`````````!)I
M:0T```<`+`8``!`````0:6D-```"`$(&````````)#$%"`8(``"@,@4(!6$`
M`*0R!0@%<@``-#$%"`<!```X,04(!P(``#PQ!0@'`P``0#$%"`<$``!$,04(
M!P4``$@Q!0@'!@``3#$%"`<'``!0,04(!U```%0Q!0@'"```6#$%"`<*``!<
M,04(!PL``&`Q!0@'#```9#$%"`<-``!H,04(!PX``&PQ!0@'#P``<#$%"`<0
M``!T,04(!Q$``'@Q!0@'$@``?#$%"`<3``"`,04(!Q0``(0Q!0@'%0``B#$%
M"`<6``",,04(!Q<``)`Q!0@'&```E#$%"`<9``"8,04(!QH``)PQ!0@'&P``
MH#$%"`<<``"D,04(!QT``*@Q!0@''@``K#$%"`<?``"P,04(!R```+0Q!0@'
M(0``N#$%"`<B``"\,04(!R,``,`Q!0@')```Q#$%"`=L``#(,04(!UD``,PQ
M!0@')0``T#$%"`<F``#4,04(!R<``-@Q!0@'*```W#$%"`<I``#@,04(!RH`
M`.0Q!0@'*P``Z#$%"`<L``#L,04(!RT``/`Q!0@'+@``]#$%"`<O``#X,04(
M!S```/PQ!0@',0```#(%"`<R```$,@4(!S,```@R!0@'-```##(%"`<U```0
M,@4(!S8``!0R!0@'-P``&#(%"`<X```<,@4(!SD``"`R!0@'.@``)#(%"`<[
M```H,@4(!SP``"PR!0@'/0``,#(%"`<^```T,@4(!S\``#@R!0@'0```/#(%
M"`=!``!`,@4(!T(``$0R!0@'0P``2#(%"`=$``!,,@4(!T4``%`R!0@'1@``
M5#(%"`='``!8,@4(!T@``%PR!0@'20``8#(%"`=*``!D,@4(!TL``&@R!0@'
M3```;#(%"`=-``!P,@4(!TX``'0R!0@'3P``58GE4X/L!.@`````6X'#<)P`
M`(N3_/___X72=`7HG@```.B]!0``Z#@U``!86\G#_S4L,04(_R4P,04(````
M`/\E-#$%"&@`````Z>#_____)3@Q!0AH"````.G0_____R4\,04(:!````#I
MP/____\E0#$%"&@8````Z;#_____)40Q!0AH(````.F@_____R5(,04(:"@`
M``#ID/____\E3#$%"&@P````Z8#_____)5`Q!0AH.````.EP_____R54,04(
M:$````#I8/____\E6#$%"&A(````Z5#_____)5PQ!0AH4````.E`_____R5@
M,04(:%@```#I,/____\E9#$%"&A@````Z2#_____)6@Q!0AH:````.D0____
M_R5L,04(:'````#I`/____\E<#$%"&AX````Z?#^____)70Q!0AH@````.G@
M_O___R5X,04(:(@```#IT/[___\E?#$%"&B0````Z<#^____)8`Q!0AHF```
M`.FP_O___R6$,04(:*````#IH/[___\EB#$%"&BH````Z9#^____)8PQ!0AH
ML````.F`_O___R60,04(:+@```#I</[___\EE#$%"&C`````Z6#^____)9@Q
M!0AHR````.E0_O___R6<,04(:-````#I0/[___\EH#$%"&C8````Z3#^____
M):0Q!0AHX````.D@_O___R6H,04(:.@```#I$/[___\EK#$%"&CP````Z0#^
M____);`Q!0AH^````.GP_?___R6T,04(:``!``#IX/W___\EN#$%"&@(`0``
MZ=#]____);PQ!0AH$`$``.G`_?___R7`,04(:!@!``#IL/W___\EQ#$%"&@@
M`0``Z:#]____)<@Q!0AH*`$``.F0_?___R7,,04(:#`!``#I@/W___\ET#$%
M"&@X`0``Z7#]____)=0Q!0AH0`$``.E@_?___R78,04(:$@!``#I4/W___\E
MW#$%"&A0`0``Z4#]____)>`Q!0AH6`$``.DP_?___R7D,04(:&`!``#I(/W_
M__\EZ#$%"&AH`0``Z1#]____)>PQ!0AH<`$``.D`_?___R7P,04(:'@!``#I
M\/S___\E]#$%"&B``0``Z>#\____)?@Q!0AHB`$``.G0_/___R7\,04(:)`!
M``#IP/S___\E`#(%"&B8`0``Z;#\____)00R!0AHH`$``.F@_/___R4(,@4(
M:*@!``#ID/S___\E##(%"&BP`0``Z8#\____)1`R!0AHN`$``.EP_/___R44
M,@4(:,`!``#I8/S___\E&#(%"&C(`0``Z5#\____)1PR!0AHT`$``.E`_/__
M_R4@,@4(:-@!``#I,/S___\E)#(%"&C@`0``Z2#\____)2@R!0AHZ`$``.D0
M_/___R4L,@4(:/`!``#I`/S___\E,#(%"&CX`0``Z?#[____)30R!0AH``(`
M`.G@^____R4X,@4(:`@"``#IT/O___\E/#(%"&@0`@``Z<#[____)4`R!0AH
M&`(``.FP^____R5$,@4(:"`"``#IH/O___\E2#(%"&@H`@``Z9#[____)4PR
M!0AH,`(``.F`^____R50,@4(:#@"``#I</O___\E5#(%"&A``@``Z6#[____
M)5@R!0AH2`(``.E0^____R5<,@4(:%`"``#I0/O___\E8#(%"&A8`@``Z3#[
M____)60R!0AH8`(``.D@^____R5H,@4(:&@"``#I$/O___\E;#(%"&AP`@``
MZ0#[____)7`R!0AH>`(``.GP^O___R5T,@4(:(`"``#IX/K__P`````Q[5Z)
MX8/D\%!44F@`R@0(:*#)!`A15FA`QP0(Z"O\___TD)"0D)"0D)"0D)"0D)!5
MB>53C60D_(`]N#(%"`!U/KL,,`4(H;PR!0B!ZP@P!0C!^P*#ZP$YV',=D(UT
M)@"-0`&CO#(%"/\4A0@P!0BAO#(%"#G8<NC&!;@R!0@!C60D!%M=PXUV`(V\
M)P````!5B>6-9"3HH1`P!0B%P'02N`````"%P'0)QP0D$#`%"/_0R<.0D)"0
MD)"0D)"0D)!5B>575HV-M/[__U.)PXVD)*#^__^#PQR)A:S^__\QP(L4@P_*
MB12!C4`!@_@0=?"-E>C^__^-3>B-M"8`````BT+L,P(S0M0S0LS!R!^)0@R-
M4@0YRG7HBY6L_O__BX6L_O__B[6L_O__BXVL_O__BYVL_O__BU($BP")E:3^
M__^+=A"+E;3^__^)A:C^__\!\HM)",'`!8F-H/[__XM;#(FUF/[__XNUI/[_
M_XF=G/[__\'&'HN]H/[__XV,`IEY@EJ+A:3^___WT(N5H/[__R'8(Y6D_O__
M"="+E;C^__\!P0':BX6H_O__BYVH_O__(?/WT".%H/[__P.]O/[__PG8BYVH
M_O__P<,>C90"F7F"6HG(P<`%`<*)T,'`!8V$!YEY@EJ)A93^__^)R(G/]]`A
MWR'P`[7`_O__"?@#A93^__^)M93^__^)UL'!'HG7]]8ASR'>`YW$_O__"?Z+
MO93^___!PAZ-M#>9>8):B;6P_O__B<;!Q@4#M;#^__^)]\''!8V\.YEY@EJ)
MPXF]E/[___?3B<<ARR'7"?L#G93^__\#C<C^__^)]XF-E/[__XGQP<`>]]$A
MQR'1"?F+O93^__\#E<S^___!QAZ-C`^9>8):B8VP_O__B=G!P04#C;#^__^)
MS\''!8V\.IEY@EJ)VHF]E/[___?2B=\APB'W`X70_O__"?H#E93^__^)A93^
M__^)R,'#'HG/]]`AWR'P`[74_O__"?B+O93^___!P1Z-A`>9>8):B86P_O__
MB="+O;#^___!P`4!QXGXP<`%C80&F7F"6HF%E/[__XG0B=;WT"'.(=@#G=C^
M__\)\`.%E/[__XF=E/[__XG[P<(>B?[WTR'6(<L)\XNUE/[__P.-W/[__\''
M'HV<'IEY@EJ)G;#^__^)P\'#!0.=L/[__XG>P<8%C;0QF7F"6HG!B;64_O__
M]]&)QB'1(?X#E>#^__\)\0.-E/[__XF5E/[__XG:P<`>B=[WTB'&(?H#O>3^
M__\)\HNUE/[__\'#'HV4%IEY@EJ)E;#^__^)RHNUL/[__\'"!0'6B?+!P@6-
ME!>9>8):B964_O__B<J)S_?2(=\AP@.%Z/[__PGZ`Y64_O__B864_O__B?#!
MP1Z)]_?0(<\AV`.=[/[__PGXB[V4_O__P<8>C80'F7F"6HF%L/[__XG0B[VP
M_O__P<`%`<>)^,'`!8V$`YEY@EJ)A93^__^)T(G3]]`A\R'(`XWP_O__"=@#
MA93^__^)C93^__^)^<'"'HG[]]$ATR'Q`[7T_O__"=F+G93^___!QQZ-C`N9
M>8):B8VP_O__B<&+G;#^___!P04!RXG9P<$%C8P.F7F"6HF-E/[__XG!B<;W
MT2'^(=$#E?C^__\)\0.-E/[__XF5E/[__XG:P<`>B=[WTB'&(?H#O?S^__\)
M\HNUE/[__\'#'HV4%IEY@EJ)E;#^__^)RHNUL/[__\'"!0'6B?+!P@6-E!>9
M>8):B964_O__B<J)S_?2(=\AP@GZ`Y64_O__P<$>`X4`____B864_O__B?")
M]_?0(<\AV`GXB[V4_O__P<8>`YT$____C80'F7F"6HGW,<^)A;#^__\QUXG0
MP<`%`X6P_O__P<(>`XT(____C;P[H>O9;HG#P<,%`?N)US'W`[4,____,<?!
MP!Z-O#FAZ]ENB=G!P04!^8G',=<#E1#___\QW\'#'HV\/J'KV6Z)SL'&!0'^
MB=\QQP.%%/___S'/P<$>C;PZH>O9;HGRP<(%`?J)SS'?`YT8____,??!QAZ-
MO#BAZ]ENB=#!P`4!QXGP,<@#C1S___\QT,'"'HV<`Z'KV6Z)^,'`!0'8B=,Q
M\P.U(/___S'[P<<>C9P9H>O9;HG!P<$%`<N)^3'1`Y4D____,<'!P!Z-M`ZA
MZ]ENB=G!P04!\8G&,?X#O2C___\QWL'#'HVT,J'KV6Z)RL'"!0'6B=HQPC'*
MC;P7H>O9;HGRP<(%`?H#A2S____!P1Z)SS'?`YTP____,??!QAZ-O#BAZ]EN
MB=#!P`4!QXGP,<@#C33___\QT,'"'HV<`Z'KV6Z)^,'`!0'8B=,Q\P.U./__
M_S'[P<<>C9P9H>O9;HG!P<$%`<N)^3'1`Y4\____,<'!P!Z-M`ZAZ]ENB=G!
MP04!\8G&,?X#O4#___\QWL'#'HVT,J'KV6Z)RL'"!0'6B=HQP@.%1/___S'*
MP<$>C;P7H>O9;HGRP<(%`?J)SS'?`YU(____,??!QAZ-O#BAZ]ENB=#!P`4!
MQXGP,<@#C4S___\QT,'"'HV<`Z'KV6Z)^,'`!0'8B=,Q\P.U4/___S'[P<<>
MC9P9H>O9;HG!P<$%`=F)^S'3`Y54____,<.)E93^___!P!Z)PB'ZC;0>H>O9
M;HG+P<,%`?.)Q@G^(<X)UHN5E/[__\'!'@.]6/___XF]E/[__XG/(<>-M#+<
MO!N/B=K!P@4!\HG."<8#A5S___\AW@G^B[V4_O__P<,>B864_O__B=@AR(VT
M-]R\&X^)WPG/B;6P_O__(=>)U@G'BX64_O__P<8%`[6P_O__P<(>`XU@____
MB8V4_O__B=&-O#C<O!N/B?#!P`4AV0'XB=<)WP.=9/___R'W"<^+C93^___!
MQAZ)G93^__^)\R'3C;PYW+P;CXG!P<$%`?F)]PG7(<<)WXN=E/[__XV\.]R\
M&X^)R\'#!0.5:/___\'`'@'[B<>)E93^__\)]XG"(?(ASPG7BY64_O__P<$>
M`[5L____B;64_O__B<XAQHV\.MR\&X^)VL'"!0'ZB<\)QP.%</___R'?"?>+
MM93^___!PQZ)A93^__^)V"'(C;P^W+P;CXG6P<8%`?Z)WPG/`XUT____(=<)
MQXN%E/[__\'"'HF-E/[__XG1(=F-O#C<O!N/B?#!P`4!^(G7"=\A]PG/BXV4
M_O__C;PYW+P;CXG!P<$%`?D#G7C____!QAZ)G93^__^)]XGS"=<ATR''`Y5\
M____"=^+G93^___!P!Z)E93^__^)PB'RC;P[W+P;CXG+P<,%`?N)QPGW`W6`
M(<\)UXN5E/[__\'!'HFUE/[__XG.(<:-O#K<O!N/B=K!P@4!^HG/"<<#180A
MWPGWB[64_O__P<,>B864_O__B=@AR(V\/MR\&X^)UL'&!0'^B=\)SR'7"<>+
MA93^__^-O#C<O!N/B?#!P`4!^,'"'@--B(G7B8V4_O__"=^)T2'9(?<)SXN-
ME/[__\'&'@-=C(F=E/[__XGS(=.-O#G<O!N/B<'!P04!^8GW"=<#59`AQPG?
MBYV4_O__P<`>B964_O__B<(A\HV\.]R\&X^)R\'#!0'[B<<)]P-UE"'/"=>+
ME93^___!P1Z)M93^__^)SB'&C;PZW+P;CXG:P<(%`?J)SPG'(=\)]XNUE/[_
M_\'#'HV\/MR\&X^)UL'&!0'^`T68B=^)A93^__\)SXG8(<@AUPG'BX64_O__
MP<(>`TV<B8V4_O__B=$AV8V\.-R\&X^)\,'`!0'XB=<)WP-=H"'W"<^+C93^
M___!QAZ)G93^__^)\R'3C;PYW+P;CXG!P<$%`<^)\0G1`U6D(<$)V8N=E/[_
M_\'`'HV,"]R\&X^)PS'SB8VP_O__,?N)^<'!!0.-L/[__\'''@-UJ(V<&M;!
M8LJ)RL'"!0'3B?HQPC'*C;06UL%BRHG:P<(%`T6LP<$>`?*)SC'^`WVP,=[!
MPQZ-M##6P6+*B=#!P`4!QHG8,<@#3;0QT,'"'HV\!];!8LJ)\,'`!0'XB=<Q
MWP-=N#'WP<8>C;PYUL%BRHG!P<$%`<^)\3'1`U6\,<'!P!Z-G`O6P6+*B?G!
MP04!V8G#,?,Q^\'''HV<&M;!8LJ)RL'"!0'3B?H#=<`QPC'*`T7$P<$>C;06
MUL%BRHG:P<(%`?*)SC'^`WW(,=[!PQZ-M##6P6+*B=#!P`4!QHG8,<@#3<PQ
MT,'"'HV\!];!8LJ)\,'`!0'XB=<QWP-=T#'WP<8>C;PYUL%BRHG!P<$%`<^)
M\3'1`U74,<'!P!Z-G`O6P6+*B?G!P04!V8G#,?,Q^XV<&M;!8LJ)RL'"!0-U
MV,'''@'3B?HQP@-%W#'*P<$>C;06UL%BRHG:P<(%`?*)SC'^`WW@,=[!PQZ-
MM##6P6+*B=#!P`4!QHG8,<@#3>0QT,'"'HV\!];!8LJ)\,'`!0'XB=<QWP-=
MZ#'WP<8>C;PYUL%BRHG!P<$%`?F)]S'7,<?!P!Z-O#O6P6+*B<O!PP4!^XG'
M`U7L,?<QS\'!'HV\.M;!8LJ)VL'"!0'7BY6H_O__`U7PC;06UL%BRHG*,<(Q
MV@'RB?[!Q@4!\HNUK/[__\'#'HD6`[VD_O__`YV@_O__`XV<_O__`X68_O__
MB7X$B5X(B4X,B480C:0D8`$``%M>7UW#C70F`(V\)P````!5B>6-9"3(B5WT
MB<,QP(7;B77XB7W\B57<=0V+7?2+=?B+??R)[%W#BQ6@,@4(A=*)5>!TY@^V
M`SP]=`2$P'5(,=*+1>"+,#'`A?9TSHE=Y(M]X(G3C78`BU7DB5PD"(E4)`2)
M-"3H$?'__X7`=0:`/!X]="N-?P2+-X7V==HQP.N9C;8`````B=J-4@$/M@(\
M/70$A,!U\BG:ZZ:-="8`BT7<*WW@P?\"B3B-1!X!Z6?___^-M@````"-OP``
M``!5B>6-9"3HC57TZ#'____)P^L-D)"0D)"0D)"0D)"0D%6)Y5:)QE.)\(U=
M](UD)/")VN@)____A<!T+I"-="8`BT7TP>`"`P6@,@4(C70F`(U`!(L0A=*)
M4/QU](G:B?#HV_[__X7`==>-9"006UY=P^L-D)"0D)"0D)"0D)"0D%6)Y593
MC60D\,<$)`````#H=_#__XL`B00DZ%WM__^)!"3HY>O__XL`BW`$QP0D````
M`.A4\/__BP")!"3H.NW__XD$).AR[/__#[88QP0D`````(/C?^@P\/__BP")
M!"3H%NW__XD$).A>[/__BP`/MT`0P>`'"=AFB48"QP0D`````.@#\/__BP")
M!"3HZ>S__XD$).AQZ___BP"+6`3'!"0`````Z.#O__^+`(D$).C&[/__B00D
MQT0D"`````#'1"0$.LP$".@^[___B4,<QP0D`````.BO[___BP")!"3HE>S_
M_XD$).@=Z___BP"+6`3'!"0`````Z(SO__^+`(D$).AR[/__B00DZ(KK__^+
M`(E#(,<$)`````#H:>___XL`B00DZ$_L__^)!"3HU^K__XL`BU@$QP0D````
M`.A&[___BP")!"3H+.S__XD$).A$[O__BP`QTH7`="/'!"0`````Z"#O__^+
M`(D$).@&[/__B00DZ![N__^+`(M0;(E3),<$)`````#H^N[__XL`B00DZ.#K
M__^)!"3H:.K__XL`BT`$QT`H`````,<$)`````#HT.[__XL`B00DZ+;K__^)
M!"3H/NK__XL`BT`$QT`8`````,<$)`````#HIN[__XL`B00DZ(SK__^)!"3H
M%.K__XL`BU@$QP0D`````.B#[O__BP")!"3H:>O__XD$).A![O__BP")0RR-
M9"006UY=PY"-M"8`````58GE5XG'5E.-I"1D____A<!T!8`X`'40C:0DG```
M`%M>7UW#C70F`(D$).BLZ___A<")QG3B9I")-"3H#.S__X7`#X30````C5@3
M#[85;<H$"`^V0!,YT'4.#[85;LH$"#A3`7329I`/MA5LR@0(.=`/A,$```")
M/"3H_>O__XD<)(E%@.CRZ___BU6`C40"`HD$).B#[/__B46$B5PD%(E\)!#'
M1"0,;\H$",=$)`C_____QT0D!`$```")!"3H*.W__XM5A(U%B(E4)`2)1"0(
MQP0D`P```.B>Z?__@_C_=`^+19@E`/```#T`0```=&Z+182)!"3HC^O__XM5
MA(D4).B$ZO__B30DZ#SK__^%P`^%,/___XDT).B\Z___B3PDZ"3L__^-I"2<
M````6UY?7<.-="8`#[8%;<H$"#A#`0^%+____P^V%6[*!`@X4P(/A.#^___I
M&O___XUV`(M%A.B8_O__ZY.-M@````!5B>56B<93,=N-9"3PQP0D`````.C3
M[/__BP")!"3HN>G__XD$).CAZ___B40D"(ET)`3'!"0#````Z/WI__^%P'0-
MC60D$(G86UY=PXUV`,<$)`````#HD.S__XL`B00DZ';I__^)!"3HGNO__XM`
M$"4`\```/0!```!T+<<$)`````#H8^S__XL`B00DZ$GI__^)!"3H<>O__XM`
M$"4`\```/0"@``!UF8DT),=$)`0"````Z)+I__\QVX7`#Y3#C60D$(G86UY=
MPY"-="8`58GE5U:)QC'`4XG3C60DQ(`Z/0^4P`'#B1PDZ!SJ__^)1=2-5>2)
M\.@C^O__A<")QW0UB00DZ`'J__\QTCE%U`^'A`$``&:0#[8$$X3`B`07C5(!
M=?(QP(UD)#Q;7E]=PXVT)@````"+%:`R!0@Q_[@(````BPJ%R706D(UT)@"-
M?P&+!+J%P'7VC02]"````(L-T#(%"(7)#X39````B40D!(D4).AQY___B<&C
MH#(%"(7)N/____]TG8T$O0````")1=#'1+D$`````(E]Y`^V!CP]#X3]````
MA,`/A/4```")\.L%D(32=`N-0`$/MA"`^CUU\8M5U"GPBWW0`SV@,@4(C40"
M`HD$).C+Z?__B<*)!X72N/____\/A#;___^+5>2AH#(%"(L$D`^V%H32B!!T
M'H#Z/709C78!ZP6`^CUT#P^V%HU``832B!"-=@%U[,8`/3'2C;0F``````^V
M#!.$R8A,$`&-4@%U\>GB_O__C70F`(E5S,<%T#(%"`$```")!"3H3^G__XG!
MBU7,A<FX_____P^$N?[__XT$O0````")#"2)3<R)1=")1"0(B50D!.B@Z?__
MBTW,B0V@,@4(Z?O^__^+1>3!X`*)1=#I^/[__XGPZ1C___^058GEC60DZ,<$
M)`````#H*>K__XL`B00DZ`_G__^)!"3'1"0,=<H$",=$)`@LEP0(QT0D!'_*
M!`CHW^G__\G#D%6)Y8UD)-C'!"0`````Z.GI__^+`(D$).C/YO__B00DZ)O_
M___'!"0`````Z,OI__^+`(D$).BQYO__B00DQT0D%`````#'1"00.LP$",=$
M)`PZS`0(QT0D"`#!!`C'1"0$F\H$".AAY___R<.-=@!5B>6-I"2XW___9:$4
M````B47D,<")7?2)=?B)??R-G>/O___H\^3__XE$)!#'1"042\P$",=$)`RP
MR@0(QT0D"`$0``#'1"0$`0```(D<).C'Z/__,?:%P'D=BU7D93,5%````(GP
M=5:+7?2+=?B+??R)[%W#9I")'"3'1"0(`!```(V]XM___XE\)`3H*NC__X7`
MB<-XPXU``8D$).BIY___A<")QG2RB5PD"(E\)`2)!"3HT^;__\8$'@#KG.BH
MY___C;8`````C;\`````58GEC60D^,GI(____XUV`%6)Y5=64XVD)+3O__^+
M70AEH10```")1>0QP+B\R@0(BWT,Z'CW___'1"0$+P```(D<)(F%U.___^B^
MY/__A<!T*HG:N,7*!`CH0OS__XM5Y&4S%10```")V`^%A`$``(VD)$P0``!;
M7E]=PXD<).A8YO__B<:)/"3'1"0$TLH$".@FY___A<")QW2VC78!B;70[___
MC;7D[___D(UT)@"`/P"X;<H$"`]$^(N%U.___X7`=!J+E=3O__^)?"0$B10D
MZ`7H__^%P`^$PP```(D\).CUY?__@'P'_R]U$&:0C4#_@'P'_R_&!`<`=/(#
MA=#O__\]_P\```^/0____XE<)!C'1"04U,H$"(E\)!#'1"0,\,L$",=$)`@`
M$```QT0D!`$```")-"3H#>?__\<$)`````#H<>?__XL`B00DZ%?D__^)!"3H
M?^;__XE$)`B)="0$QP0D`P```.AKX___A<!U+<<$)`````#H.^?__XL`B00D
MZ"'D__^)!"3H2>;__XM`$"4`\```/0"```!T(\=$)`32R@0(QP0D`````.@&
MYO__A<")QP^%\/[__^F-_O__QT0D!`$```")-"3H1^3__X7`=<F)\KC%R@0(
MZ+OZ__^)-"3H#^?__XG#Z6K^___HH^7__XVT)@````!5B>6+10@/M@B$R703
MC5`!@/DO#[8*#T3"A,F-4@%U\%W#C;0F`````(V\)P````!5B>53C60D[(M=
M"(7;="F`.P!T)(D<).B0Y/__C40#_SG#<@OK/F:0C4#_.<-S-8`X+W3TZR=F
MD,<$)`(```#H".7__X7`=`5FQP`N`(UD)!1;7<.-="8`@#@O=`>-0/\YPW+T
M.=AU&(`X+W1;QT4(U,H$"(UD)!1;7>E-YO__D(U`_SG#<P6`."]T](G",<`I
MVHU*`H'Y`!```'>PC5(!QT0D#``0``")5"0(B5PD!,<$).`R!0CHD.'__[C@
M,@4(ZXJ0C70F`,<$)`(```#H>.3__XG",<"%T@^$;?___V;'`BX`B=#I8?__
M_XUT)@!5B>575HUD)-!EH10```")1?0QP*%8S`0(B472H5S,!`B)1=:A8,P$
M"(E%VJ%DS`0(B47>H6C,!`B)1>*A;,P$"(E%YJ%PS`0(B47JH73,!`B)1>X/
MMP5XS`0(9HE%\KC6R@0(Z$?T__^XW\H$".@]]/__N.?*!`CH,_3__[CPR@0(
MZ"GT__^X]\H$".@?]/__N`?+!`CH%?3__[B\R@0(Z`OT__^X$\L$".@!]/__
MN!W+!`CH]_/__[@GRP0(Z.WS__^XQ<H$".CC\___N#'+!`CHV?/__[@ZRP0(
MZ,_S__^X1<L$".BE\___A<!T#(G"N!W+!`CHA?C__[A6RP0(Z(OS__^%P'0,
MB<*X:,L$".AK^/__N'/+!`CH<?/__X7`=#6)PKB\R@0(Z%'X__^ZG\L$"+CW
MR@0(Z$+X__^+1?1E,P44````=4Z-9"0P7E]=PXVV`````+B#RP0(Z"[S__^%
MP'02B<*X$\L$".@.^/__Z[N-="8`C77COY3+!`BY"@```/.F=::-5>VX$\L$
M".CJ]___ZY?HW^+__XUV`%6)Y8UD)/BA?#(%"(/X_W0'R<.0C70F`+@3RP0(
MZ,[R__^)PC'`A=)T#P^V$H32=`@QP(#Z,`^5P*-\,@4(R<-5B>6-9"3HZ!#B
M__^)!"3HZ.'__XG",<"%TG0"BP+)PU6)Y5=6C7744[NKRP0(C60DI,=%T*O+
M!`B+?0C'1=2ARP0(QT78KLL$",=%W*3+!`C'1>"IRP0(QT7D.LP$".LDC;0F
M`````(E\)`2)!"2)1<3H]>'__X7`=#V+'HUV!(`[`'0CB=CH)/+__X7`=`6`
M.`!UTXG8B?KH`O?__XL>C78$@#L`==V-9"1<6UY?7<.-M"8`````B3PDZ!SA
M__^+5<2)1<")%"3H#N'__XM-P(U$`0*)!"3HG^'__XM5Q,=$)!32R@0(B50D
M&(E\)!#'1"0,\,L$",=$)`C_____QT0D!`$```")!"2)1<#H.>+__XM-P(G8
MB<KH@?;__^E7____C;8`````C;\`````58GE5U93C:0DM'[__XM%"(F%^'[_
M_[B\R@0(98L5%````(E5Y#'2QX4H?___Q\L$",>%+'___\_+!`C'A3!___]M
MR@0(QX4T?___.LP$",>%$'___VC+!`C'A11___]ARP0(QX48?___U,L$",>%
M''___\K+!`C'A2!____<RP0(QX4D?___.LP$",>%.'___[O+!`C'A3Q____@
MRP0(QX5`?___.LP$".C2\/__A<!T"8`X``^%)0,``)"-="8`Z`O^__^%P(G'
M#X0Y`P``#[8?A-MT(NA1W___B?J-=@"+"`^^V_8$60AU`\8"7XU2`0^V&H3;
M=>B[`0```+AHRP0(ZQ>-="8`BX2=$'___XU;`8`X``^$;0(``.A@\/__A<")
MQG3BZ'7T__^%P'39B30DZ)7A__^%P'3-B<:)-"3H9]___XG#B3PDZ%W?__^-
ME`,$!```B10DB97T?O__Z.C?__^+E?1^__^)PXD4)(F%_'[__^C2W___B84`
M?___B7PD',=$)!CIRP0(QT0D%-3*!`B)="00QT0D#.[+!`C'1"0(_____\=$
M)`0!````B00DZ&3@__^+O0!____'1"0$[0$``(D\).A>W/__N*3+!`CHJ.__
M_X7`#X1H`@``B00DZ.3@__^+E?A^__^)1"0$BP*)!"3HY/?__X7`B84$?___
M#X0^`@``BX4$?___B00DZ)3>__^#^`-^,XN5!'___[_WRP0(N04```"-=`+\
M\Z9U&X/X!`^$B@8``(N]!'___X!\!_LO#X1Y!@``D.@[_/__A<!U)(N5!'__
M_\=$)`0`````B10DZ-W?__^%P(F%!'___P^%XP$``+J?RP0(N!/+!`CHY//_
M_^B+V___B[T`?___QT0D'#K,!`B)?"00B40D&,=$)!34R@0(QT0D#!7,!`C'
M1"0(_____\=$)`0!````B1PD,?;H2]___XN]`'___^M5C;0F`````.@7V___
M@S@1=5GH+=O__XUV`<=$)"`ZS`0(B70D'(E$)!C'1"04U,H$"(E\)!#'1"0,
M(\P$",=$)`C_____QT0D!`$```")'"3H[M[__\=$)`3M`0``B1PDZ.[:__^#
M^/]TG8N%`'___XD$).AKW/__B=JXO,H$".@3\___B1PDZ(O[__^+5>1E,Q44
M````BX7\?O__#X6-!@``C:0D3($``%M>7UW#D(NU*'___[L!````@#X`=1?K
M/XVV`````(NTG2A___^-6P&`/@!T*HGPZ.KQ__^%P'3FB30DZ`K?__^%P`^%
M<?W__XNTG2A___^-6P&`/@!UUC'VZ5W]__^)!"2)A?1^___H`OO__XN%]'[_
M_XD$).C0WO__B87\?O__Z5[___^0NP$```"XN\L$".L7C70F`(N$G3A___^-
M6P&`.``/A.T$``#H4.W__X7`=.2)!"3HD-[__X7`=-B)Q^F(_/__D(N]^'[_
M_XL_B;T$?___Z:_]__^0C70F`,=$)`P"````QT0D!.[____'1"0(_____XD$
M).A\VO__BX4$?___QT0D"`8```"-O41___^)!"2)?"0$Z.S:__^`O41___\`
M=0V`O45___]##X2[!```BX4$?___QT0D#`````#'1"0$`````,=$)`@`````
MB00DZ"#:__^-E6#____'A43___\!(T5GQX5(____B:O-[\>%3/____[<NIC'
MA5#___]V5#(0QX54____\.'2P\>%6/___P````#'A5S___\`````QT6@````
M`(F5Y'[__XF=^'[__Y"-="8`BX4$?___QT0D"`"```"-O41___^)!"2)?"0$
MZ"S:__^%P(G##XY^`0``BY58____C;U$?___C03:B858____.=")V`^2P@^V
MT@&57/___\'H'0&%7/___XM%H(7`=%F_0````(V58/___RG'C00".?N-E41_
M__^)!"2)5"0$#T[[B7PD".C"VO__BT6@`?B#^$")1:`/A67___^-A41___\I
M^XT\.(V%1/___^C?W?__C;0F`````(/[/P^.O````#'VD(UT)@"+!#>)A6#_
M__^+1#<$B85D____BT0W"(F%:/___XM$-PR)A6S___^+1#<0B85P____BT0W
M%(F%=/___XM$-QB)A7C___^+1#<<B85\____BT0W((E%@(M$-R2)182+1#<H
MB46(BT0W+(E%C(M$-S")19"+1#<TB464BT0W.(E%F(M$-SR)19R-A43____H
M-MW__XG8C79`*?"#^#\/CU[___^-6\")V,'H!HG"P>(&*=.-?#I`C95@____
MQT0D#$0```")7"0(B7PD!(D4).B1V/__B5V@Z5W^__^0C70F`(N5!'___XN=
M^'[__XD4).@@VO__B[58____BY5<____B?#!Z`.#X#_&A`5@____@(/``8/X
M.`^/_@$``+DX````C;U@____*<&)E?1^__^-!`>)3"0(QT0D!`````")!"3H
M[M?__XN5]'[__XG0B%6;P>@8C7VGB$68B=#!Z!"(19F)T,'H"(A%FHGPP>@8
MB$6<B?#!Z!"(19V)\,'H"(A%GHGPB$6?C85$____Z#;<__^+E43___\Q]HG1
MB%73P>D8B<B(3=")T<'I$(A-T8G1P>D(BY5(____B$W2B='!Z1B(5=>(3=2)
MT<'I$(A-U8G1P>D(BY5,____B$W6B='!Z1B(5=N(3=B)T<'I$(A-V8G1P>D(
MBY50____B$W:B='!Z1B(5=^(3=R)T<'I$(A-W8G1P>D(BY54____B$W>B='!
MZ1B(5>.(3>")T<'I$(A-X8G1P>D(B$WBZPB-=@`/MD0UT`^VP,=$)`P0S`0(
MB40D$(T$=XUV`<=$)`C_____QT0D!`$```")!"3HHMG__X/^%'7)BY4`?___
MQD7/`,=$)!PZS`0(B7PD&,=$)!34R@0(B50D$,=$)`P!S`0(QT0D"/_____'
M1"0$`0```(D<).A;V?__Z7WZ__]FD(N%^'[__XM0!(72#X1W^?__B10DB97T
M?O__Z,77__^#^`.+E?1^__\/AEKY__^-=`+\O_S+!`BY!0```/.F#T65!'__
M_XF5!'___^DX^?__O\#+!`CIUO?__[E`````C;U@____*<&)E?1^__^-!`>)
M3"0(QT0D!`````")!"3H\-7__XV%1/___^AYVO__N0X````QP(N]Y'[___.K
MBY7T?O__Z>/]__^`O49___]!#X4X^___@+U'?___0P^%*_O__X"]2'___T@/
MA1[[__^`O4E___]%#X41^___BY4$?___QT0D#`(```#'1"0$QO___\=$)`C_
M____B10DZ#'5__^+A01___^)?"0$QT0D""D```")!"3HI]7__XE\)!B+O0!_
M___'1"0<.LP$",=$)!34R@0(B7PD$.F9_O__Z%_7__^-=@!5B>575E.-I"3$
M[___QP0D`````&6A%````(E%Y#'`Z%C8__^+`(D$).@^U?__B00DZ+;5___&
M``&X]\H$".@MY___A<!T"8`X,0^$*`,``.B+\O__QP0D`````.@;V/__BP")
M!"3H`=7__XD$),=$)`P+````QT0D"`$```#'1"0$-,P$".B1U/__A<`/A-T`
M``"+0`PQ]HM`&(F%U.___Z'(,@4(@_@!#XZV````NP$```#K,6:0BT<,BQ7$
M,@4(BQ2:B40D!(D4).C,U___A<`/A8@```"-6P&AR#(%"#G8C78!?G['!"0`
M````Z(G7__^+`(D$).AOU/__BY74[___QT0D#`````")="0(B50D!(D$).C1
MU?__A<!T08LX]D<)!'61QP0D`````.A)U___BP")!"3H+]3__XD$),=$)`P"
M````QT0D"`````")?"0$Z)/7___I7?___V:0H<@R!0B-4/\Y\@^$F`$``,<$
M)`````#H`-?__XL`B00DZ.;3__^)!"3'1"0,!````,=$)`@!````QT0D!#G,
M!`CH=M/__X7`B<-T/HM`#(LPQP0D`````.B_UO__BP")!"3HI=/__XD$),=$
M)`@[S`0(B70D!.AAT___BT,,BQCV0PI`#X5F`0``QP0D`````.B&UO__BP")
M!"3H;-/__XD$),=$)`P$````QT0D"`$```#'1"0$0\L$".C\TO__A<")PW0_
MN,7*!`CH0.7__X7`B<8/A$X!``"+0PR+.,<$)`````#H,=;__XL`B00DZ!?3
M__^)!"2)="0(B7PD!.C7TO__QP0D`````.@+UO__BP")!"3H\=+__XD$).AI
MT___Q@``QP0D`````.CJU?__BP")!"3HT-+__XD$).@(UO__QP``````N+S*
M!`CHO.3__X7`H\PR!0@/A+`!``#'1"0$[0$``(D$).A+T?__@_@1=!"%P'0,
M@_C_C78`#X7U`0``BT7D93,%%`````^%X`$``(VD)#P0``!;7E]=PXVV````
M`(/X`0^.7_[__[L!````9I#'!"0`````C5L!Z%75__^+`(D$).@[TO__BY74
M[___B00DB50D!.C)T?__.1W(,@4(?\WI(/[__\<$)`````#H(-7__XL`B00D
MZ`;2__^)!"2)7"0$Z-K3___I<_[__Y"`>`$`#X33_/__Z<G\__^0H<0R!0B-
MO>3O__^+`(F%T.___XM##(L`QP0D`````(F%U.___^C*U/__BP")!"3HL-'_
M_\=$)`C_#P``B7PD!,<$)$#,!`CHV-/__X7`B<9^8(U`_X"\!>3O__\`=0:%
MP'1/B<:)="0(QT0D!"\```")/"3H&]3__X7`=#7'!"0`````Z&O4__^+`(D$
M).A1T?__BY74[___B70D#(E\)`B)5"0$B00DZ)?2___I*_[__\<$)`````#H
M-M3__XL`B00DZ!S1__^+E=#O__^)!"2)5"0(BY74[___B50D!.C0T/__Z?3]
M__^AQ#(%"(D$).AR\?__H\PR!0B+0PR+/<0R!0B+,/9&"00/A)L```"+1@R)
M?"0$B00DZ.71__^)QHM##(L8]D,)!'1+BT,,B40D"*'$,@4(B70D#(L`QP0D
M?,P$"(E$)`3H]M+__^B!TO__B40D#*',,@4(B40D"*'$,@4(BP#'!"2LS`0(
MB40D!.C-TO__QP0D`````.AQT___BP")!"3H5]#__XD$),=$)`P"````QT0D
M"`````")7"0$Z+O3___KA,<$)`````#H/=/__XL`B00DZ"/0__^)!"3'1"0,
M`@```,=$)`@`````B70D!.B'T___Z3'___^-M@````!5B>564XUD)/"+=0B)
M-"3H;.S__P^V$(G#A-)T$XU``8#Z+P^V$`]$V(32C4`!=?#HV^[__X7`=!V%
M]G09@#X`=!3'1"0$Z<L$"(D<).AJT?__.=AT"(UD)!!;7EW#C60D$(GP6UY=
MZ43D__^-="8`58GEC60DZ,<$)`````#HB=+__XL`B00DZ&_/__^)!"3'1"0$
M_____^BOS___QP0D`````.ACTO__BP")!"3H2<___XD$),=$)`@`````QT0D
M!/"H!`CHH=+__\G#C78`58GE@^3P5E.-11"-9"3(B40D"(U%#(E$)`2-10B)
M!"3H!]+__\=$)`A<E00(QT0D!%R5!`C'!"0\EP0(Z-\!``#'!"0`````Z`_/
M__^`.`!U.^CUSO__A<"CP#(%"`^$L`$``(D$).BPS___QP0D`````.C$T?__
MBP")!"3HJL[__XD$).@2T?__Q@``QP0D`````.BCT?__BP")!"3HB<[__XD$
M).BAT?__@`@"QP0D`````.B"T?__BP")!"3H:,[__XD$).B`T?__@`@!BT4(
M@\`%,<F)1"0HB4PD+-]L)"C8!?S,!`C=!0#-!`C9R=_IW=@/AP4!``#!X`*)
M!"3HIM#__XMU#*/$,@4(BQ;'0`1/S`0(B1#'0`@@S00(QT`,4LP$"(M="(/[
M`<<%R#(%"`0```!^%;H!````9I"+#):)3)`,C5(!.=IU\HU;`\<$F`````")
M1"0,H<`R!0B)7"0(QT0D$`````#'1"0$@*\$"(D$).B/S/__A<")PW0]H<`R
M!0B)!"3H3,___[@'RP0(Z);?__^%P'0ZH<`R!0B)!"3H0<S__^@<SO__C60D
M.(G86UZ)[%W#C70F`*'`,@4(B00DZ._,__^)P^NRC;0F`````*',,@4(A<!T
M"HD$).A'_?__Z[.XO,H$".@[W___A<"CS#(%"'2@Z^''1"0$I#(%",<$)+G*
M!`CH>,___\<$)`$```#H;-#__U6)Y5/H,@```('#OV<``(/L$(N#0)G__XE$
M)`R+11")1"0(BT4,B40D!(M%"(D$).A'S/__@\006UW#BQPDPY!5B>575E/H
M\/___X'#?6<``(/L'.CSRO__C;O8_O__C8/8_O__*<?!_P*%_W0D,?:+11")
M1"0(BT4,B40D!(M%"(D$)/^4L]C^__^#Q@$Y_G+>@\0<6UY?7<.-M@````!5
MB>5=PY"0D)"0D)"0D)"058GE4XUD)/RA`#`%"(/X_W02NP`P!0B0C5O\_]"+
M`X/X_W7TC60D!%M=PY!5B>53@^P$Z`````!;@</@9@``Z-S/__]96\G#````
M```````#`````0`"```````N+@`E<R\E<P!P97)L>'-I+F,`1'EN84QO861E
M<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C
M+R5I+R5S`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$52
M3$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!
M4E]!4D=67S``4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!0
M05)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!
M4E]#3$5!3CT`,0!,24)0051(`$193$1?3$E"4D%265]0051(`%5315(`4UE3
M5$5-`$,Z7%1%35``+W1M<`!414U01$E2`%1-4`!54T523D%-10!P87(M`"5S
M)7,E<R5S`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E,#)X`"5S)7-T96UP
M+25U)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``O<')O8R]S96QF
M+V5X90`M90`M+0````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M(``````E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I
M=&@@)6DN"@`E<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@``````
M`````(#____/07!A<BYP;````````````````````````",A+W5S<B]B:6XO
M<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B
M?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*
M<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T
M('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T
M<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`
M=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E
M<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64[
M"B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG
M="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I
M=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N
M"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![
M"B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE
M('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L
M;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI
M;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S
M('1H870@87)E(&EN('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@
M("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N
M9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG="!D
M;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C
M97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN
M9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@
M("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@
M("`@("`@("!3549&25@@/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@
M/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO
M<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D
M<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@H@
M("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K
M(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@
M("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@;7D@
M)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<[
M"B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D["B`@
M("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P
M97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL96YA
M;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"
M3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@
M979A;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%2
M7T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`]
M(&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#
M?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@
M("`@9F]R("AK97ES("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@
M:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0
M051("FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^
M("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D
M7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL
M"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<
M7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP
M*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B
M=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I
M.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C
M($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![
M>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@
M8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L
M(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B
M=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@
M("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A
M8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@
M("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C
M($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@
M)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@
M("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE
M(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L
M;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^
M('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M
M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI
M*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@
M(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@
M:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\
M86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@
M7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@
M>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@
M("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O
M=70["B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@
M("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O
M?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@("`@
M(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@
M;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B
M.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@
M("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@
M)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R
M:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@
M("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[
M)&9U;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#
M86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B
M=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@
M("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@("`@("`@
M('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]
M"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@
M)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE
M(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@
M)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY
M("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES
M="D@>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%
M)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@
M:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@("`@
M("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE
M(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F
M24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D
M92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F
M?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R
M971U<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N
M86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@
M("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@
M)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO<V4@
M)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@
M)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H
M*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@
M(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U
M;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N
M9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C
M="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER
M92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE
M;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE
M.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@
M*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI
M('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I
M9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL
M96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@
M("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE
M<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M("`@("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP
M($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@
M("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*
M"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP
M,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]
M"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@
M*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*9&5L971E
M("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B
M92!A('-E8W5R:71Y('!R;V)L96TI"@HD<75I970@/2`P('5N;&5S<R`D14Y6
M>U!!4E]$14)51WT["B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O
M;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H
M(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F
M)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@
M("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@
M('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@
M("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@("`@(R!I9B!T:&4@87!P(&ES
M(&EN=F]K960@87,@(F%P<&YA;64@+2UP87(M;W!T:6]N<R`M+7)E=7-E(%!2
M3T=204T@0%!23T=?05)'5B(L"B`@("`C('5S92!T:&4@87!P('1O(')U;B!T
M:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E860@;V8@86YY=&AI;F<@9G)O;2!T
M:&4*("`@(",@87!P(&ET<V5L9B`H8G5T('-T:6QL('-E="!U<"!T:&4@;F]R
M;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@0$E.0RD*("`@(&EF("A`05)'5B!A
M;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["B`@("`@("`@<VAI9G0@0$%2
M1U8["B`@("`@("`@)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6
M.PH@("`@?0H@("`@96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"@H@
M("`@("`@(&UY($!A9&1?=&]?:6YC.PH@("`@("`@('=H:6QE("A`05)'5BD@
M>PH@("`@("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PH*("`@("`@("`@("`@:68@*"0Q(&5Q("=))RD@
M>PH@("`@("`@("`@("`@("`@<'5S:"!`861D7W1O7VEN8RP@)#(["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=-)RD@>PH@("`@
M("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@("`@("`@("`@("`@("!U
M;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@("`@("`@("`@)&]U="`]
M("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M8B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G<VET92<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=")RD@>PH@("`@
M("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I('L*("`@("`@("`@("`@("`@
M("1Q=6EE="`](#$["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^
M/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)U0G*2!["B`@
M("`@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!S:&EF="A`05)'5BD["@H@("`@("`@("`@("!I9B`H
M;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@("`@(&1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@("`@("`@("`@("`@:6YI=%]I
M;F,H*3L*("`@("`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@
M("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%2
M1U8["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@
M9F]R($!!4D=6.PH@("`@("`@("`@("`@("`@97AI=#L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@=6YS:&EF="!`24Y#+"!`861D7W1O7VEN
M8SL*("`@('T*?0H*(R!86%@@+2T@861D("TM<&%R+61E8G5G('-U<'!O<G0A
M"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L:6YG('M[>PII9B`H
M)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`]
M(%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER
M92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@
M('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PH@("`@;7D@)'II<#L*
M"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@;7D@)&9H
M+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*
M("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@
M("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@("`@("`@("`@;W(@9&EE
M(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E96YV
M(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M
M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@("`@("`@("1M971A(#U^
M(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D;65T82`]?B!S+UY<4RXJ
M+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD
M+VUG.PH@("`@("`@('T*("`@('T["@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O
M=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`](%PT.PH*("`@(&EF("AD
M969I;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R
M(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO9&4H4$%2*3L*("`@("`@
M("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E
M<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E871E4&%T:"@D;W5T*2`[
M"B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<H"B`@("`@("`@)&]U
M="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?
M5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`H@("`@("`@(#`W-S<L
M"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]
M("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["B`@
M("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D97(@/2!S8V%L87(@/%]&
M2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]
M?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@?0H@("`@9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@("`@(&UY("1V86P@/2`D
M96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A;"`](&5V86P@)'9A;"!I
M9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@)&UA9VEC(#T@(E]?14Y6
M7U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@("`@(&UY("1S970@/2`B
M4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@("`@("`@)&QO861E<B`]
M?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D;6%G:6,@+B`D<V5T("X@
M*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*("`@("`@("!]
M96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U
M;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B=6YD;&5D(&UO9'5L97,@
M>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@(')E<75I<F4@4$%2.CI(
M96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"B`@("`@("`@:6YI=%]I;F,H*3L*"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S
M*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@("`@("`@("`@;&5N
M9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@9W)E<"!["B`@("`@
M("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@
M("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@("`@*"1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@("`@("`@("`@("1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@("`@("`@?2!`
M24Y#.PH*("`@("`@("`C($9I;&4@97AI<W1S('1E<W0@861D960@=&\@9FEX
M(%)4(",T,3<Y,#H*("`@("`@("`C($9U;FYY+"!N;VXM97AI<W1I;F<@96YT
M<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]287<O6FQI8B]A=71O<W!L:70N
M:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@8F%N9"UA:60@9FEX('=I=&@@;F\@
M9&5E<&5R(&=R87-P(&]F('1H92!I<W-U92X*("`@("`@("`C(%-O;65B;V1Y
M('!L96%S92!G;R!T:')O=6=H('1H92!P86EN(&]F('5N9&5R<W1A;F1I;F<@
M=VAA="=S(&AA<'!E;FEN9RP*("`@("`@("`C($D@9F%I;&5D+B`M+2!3=&5F
M9F5N"B`@("`@("`@;7D@)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD
M("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@
M("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY
M("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S
M*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@
M("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@("!I
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@
M("`@("`@("`@("`@("`@("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@
M("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L
M<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@
M("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@
M("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@
M)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T
M("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@
M("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI
M;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@
M("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@("`@
M("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL92DI
M('L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@
M("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D
M9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@
M("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@
M("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@
M("`@("`@("`@("`@("!I9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M
M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@(R!$
M;R!N;W0@;&5T(%A33&]A9&5R('!I8VL@=7`@875T;R\J(&9R;VT@96YV:7)O
M;FUE;G0*("`@("`@("`@("`@("`@("1C;VYT96YT(#U^(',O9V]T;R`K<F5T
M<GD@*W5N;&5S<R`K+BHO9V]T;R!R971R>3LO"B`@("`@("`@("`@("`@("`@
M("`@:68@;&,H)&YA;64I(&5Q(&QC*")84TQO861E<BYP;2(I.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE
M(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*")&24Q%(BD["B`@("`@("`@
M("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D[
M"B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R:6YT9B@*("`@("`@("`@("`@
M("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O
M;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I*3L*("`@("`@("`@("`@)&9H
M+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@("`@
M("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@("!]"B`@("!]"B`@
M("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I
M8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H
M*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N
M86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@("`@(&UY("1C='@@/2!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]
M"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@
M1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@
M("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N
M9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E
M<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@:68@*"1S:&%?=F5R
M<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@
M("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I
M.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@:68@*"1C
M='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@("`@("`@("`@("`@
M("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL
M92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A8VAE7VYA;64@/2`D8W1X(#\@
M)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE7VYA
M;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@("`D
M8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C:&5?
M;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L
M96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^<')I;G0H(EQN4$%2+G!M7&XB
M*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@("`@
M(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N86UE
M(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL97-S(&1E
M9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N86UE*"D["@H@("`@
M(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD('!U="!I="!I;G1O(%!!4CHZ
M3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@>PH@("`@("`@("-L;V-A;"`D
M24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<[
M"B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@("`@(')E<75I<F4@
M07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*("`@
M("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@("!P
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%2
M7U1%35!](BDI.PH*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![
M(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0H@("`@("`@(&9O<F5A
M8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@("`@("`@
M(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@("`@("`@("`@(&UY
M("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PH@("`@("`@("`@
M("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*("`@("`@("`@("`@
M("`@(%X*("`@("`@("`@("`@("`@("\_<VAL:6(O"B`@("`@("`@("`@("`@
M("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@("`@("`@
M("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@("`@("`@
M("`@("`@("A;7B]=*RD*("`@("`@("`@("`@("`@("0*("`@("`@("`@("`@
M?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T7VYA;64@/2`D,3L*("`@("`@
M("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PH@("`@("`@("`@("!I9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A3:VEP<&EN9R`B
M)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E
M<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E
M<W1?;F%M92(I*3L*("`@("`@("`@("`@("`@("1M96UB97(M/F5X=')A8W14
M;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@("`@("`@("`@("`@(&-H;6]D
M*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"B`@("`C('U]?0I]"B,@?7U]"@HC($EF
M('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM["G5N
M;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE(#P\
M("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@
M+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L
M(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI
M9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T:"!["B`@("!M>2`H
M)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64[
M"B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E
M;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@("`*("`@(')E
M<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE<R!["B`@("`C;&]C86P@)$E.
M0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH*
M("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@("`@
M<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I8W0["B`@("!R97%U
M:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER92!#
M87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17)R
M;F\["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(')E<75I<F4@
M17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&:6QE
M.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER92!8
M4TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)3SHZ
M2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@(')E<75I<F4@0V]M
M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@(')E
M<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER
M92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*("`@(')E<75I<F4@871T<FEB=71E<SL*("`@(&5V86P@>R!R97%U:7)E
M($-W9"!].PH@("`@979A;"![(')E<75I<F4@5VEN,S(@?3L*("`@(&5V86P@
M>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@("`@979A;"![(')E<75I<F4@
M07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["B`@("!E=F%L('L@<F5Q=6ER92!4
M:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PH@("`@979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["GT*"B,@5&AE($,@
M=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I
M<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@:6X@4$%2.CI3971U<%1E;7`@
M87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S971?<&%R7W1E;7`@>PH@("`@
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@
M(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY("1P871H("@*("`@("`@
M("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*
M("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD
M("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64[
M"B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E
M=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H
M)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@("`@:68@*"!D969I;F5D*"97
M:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@
M)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("AD
M969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D<'=U
M:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D=7-E
M<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-4
M14TG.PH@("`@("`@('T*("`@("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<[
M"@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]
M<&%R+21U<V5R;F%M92(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@("`@("`@("`@(&]P96X@*&UY
M("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@("`@("`@("!S965K("1F:"P@
M+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*
M("`@("`@("`@("`@:68@*"1B=68@97$@(EPP0T%#2$4B*2!["B`@("`@("`@
M("`@("`@("!S965K("1F:"P@+34X+"`R.PH@("`@("`@("`@("`@("`@<WES
M<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@("`@("`@("`@)&)U9B`]?B!S
M+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@
M("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@("`@("`@("!\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE
M=R!].PH*("`@("`@("`@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN
M($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("`@("`@("`@(&UY
M("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@
M?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G
M-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@
M("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D
M8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F
M:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!B
M:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@("1C='@M/F%D
M9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@8VQO<V4H)&9H
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@
M('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)$5.5GM005)?0TQ%04Y]
M(#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@("`@)$5.5GM005)?5$5-4'T@
M/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@
M("`@("!L87-T.PH@("`@?0H*("`@("1P87)?=&5M<"`]("0Q(&EF("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*"G-U
M8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@("!M
M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F:6QE;F%M92`]("(D<&%R7W1E
M;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@
M("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*("`@("`@
M("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64["B`@("!]"B`@("!E;'-E('L*
M("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL
M96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O
M<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["B`@("!R971U<FXH)&9H+"`D
M9FEL96YA;64I.PI]"@HC('-A;64@8V]D92!L:79E<R!I;B!005(Z.E-E='5P
M4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@7W-E=%]P<F]G;F%M92!["B`@
M("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@("`D<')O9VYA;64@/2`D
M,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P.PH*("`@(&EF("@D14Y6
M>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0
M?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA
M;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*
M("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@(&EF
M("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*("`@("`@("`@("`@
M<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@("`@("`@:68@*"US("(D
M<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@("`@("`@("`D<')O9VYA
M;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@
M("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#
M;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@("`@;F5X
M="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM0
M05)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]
M7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*("`@("`@("`@
M("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG
M>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*?0H*<W5B(%]F
M:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%2
M7U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@(BXD0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@(",@6%A8("T@:&%C:R!T
M;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@("`@("`@("`@(#H@*"AD
M969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P
M=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R;V=N86UE(#U^(',O7B@_
M/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM
M?2\["@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"@IS
M=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N.PH@("`@?2!E;'-E('L*
M("`@("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PH@("`@?0H*("`@
M(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'
M3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@(&1E;&5T92`D14Y6>R=0
M05)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I9B`H)$5.5GM005)?5$5-
M4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM005)?0TQ%04Y].PH@("`@?0H@
M("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PH@
M("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE
M;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@)#$@
M:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*("`@('T*?0H*<W5B
M(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G9F@I
M('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@96QS
M92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI=%]I
M;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P=7-H($!)3D,L(&=R97`@
M9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@("`@
M(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP
M"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*("`@("D["GT*
M"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC(%1H92!M86EN('!A8VMA
M9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E<75I
M<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI
M;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@
M<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E
M8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA;64["@ID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?7T524D]2(#T@)$`@:68@
M)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/
M4CL*"C$["@HC;&EN92`Q,#$R"@I?7T5.1%]?"@````$;`SOH````'````+1Q
M__\$`0``I'[__S0!``!D?___9`$``(1___^$`0``Y'___[`!```4@O__W`$`
M`(2#__\<`@``5(3__U0"```TAO__A`(``'2&__^D`@``Y(;__\0"``"TA___
M]`(``,2'__\4`P``M(G__T0#``#DB?__9`,``-2*__^8`P``=(S__\0#``"T
MC/__[`,``-2,__\,!```Y(W__SP$``#TE___<`0``&2=__^@!```U)W__]0$
M```TGO__]`0``%2@__\T!0``CZ#__U@%``"4H/__;`4``/2@__^8!0``%```
M```````!>E(``7P(`1L,!`2(`0``+````!P```"H</__Y0P```!!#@A"A0(-
M!4N#!88$AP,#TPS#0<9!QT'%#`0$````+````$P```!H??__M`````!!#@A"
MA0(-!4F#!4^'`X8$2PH-!,?&PT'%#@1!"P``'````'P```#X??__$0````!!
M#@A"A0(-!4W%#`0$```H````G````/A]__]1`````$$."$*%`@T%0X8#1H,$
M`D+#0<9!Q0P$!````"@```#(````+'[__R@"````00X(0H4"#05-@P2&`P,5
M`L-!QD'%#`0$````/````/0````P@/__:@$```!!#@A"A0(-!4.'`TV#!88$
M30K#0<9!QT'%#`0$10L#"`$*PT'&0<=!#`0$Q44+`#0````T`0``8('__\L`
M````00X(0H4"#05#A@-#@P0"00K#0<9!Q0P$!$0+`GC#0<9!#`0$Q0``+```
M`&P!``#X@?__WP$```!!#@A"A0(-!42&!(<#18,%`E$*PT'&0<=!Q0P$!$@+
M'````)P!``"H@___/P````!!#@A"A0(-!7O%#`0$```<````O`$``,B#__]M
M`````$$."$*%`@T%`FG%#`0$`"P```#<`0``&(3__\0`````00X(0H4"#05A
MAP.&!(,%`E`*#03'QL-!Q0X$0PL``!P````,`@``N(3__PT`````00X(0H4"
M#05%Q0P$!```+````"P"``"HA/__Z0$```!!#@A"A0(-!4V#!88$AP,"6`K#
M0<9!QT'%#`0$00L`'````%P"``!HAO__(@````!!#@A"A0(-!5[%#`0$```P
M````?`(``'B&___L`````$$."$*%`@T%2(,#`D<*PT'%#`0$10MA"L-!Q0P$
M!$8+````*````+`"```TA___G0$```!!#@A"A0(-!0)AA@2'`P+K"L9!QT'%
M#`0$1PLD````W`(``*B(__]``````$$."$*%`@T%3PK%#`0$1@MG#`0$Q0``
M'`````0#``#`B/__(`````!!#@A"A0(-!5S%#`0$```L````)`,``,"(__\$
M`0```$$."$*%`@T%188$AP-&@P4"?PK#0<9!QT'%#`0$2`LP````5`,``*")
M__\-"@```$$."$*%`@T%`J:#!88$AP,#V@(*PT'&0<=!Q0P$!$(+````+```
M`(@#``!\D___:@4```!!#@A"A0(-!5R#!88$AP,#WP(*PT'&0<=!Q0P$!$<+
M,````+@#``"\F/__;`````!!#@A"A0(-!4F#!(8#`D\*PT'&0<4,!`1!"T?#
M0<9!Q0P$!!P```#L`P``^)C__UT`````00X(0H4"#04"6<4,!`0`/`````P$
M```XF?__(`(```!!#@A"A0(-!5T0`P=U``GP&C@<$`8'=0`)\!HT'`.7`0K#
M0<9"#01!Q0X$10L``"````!,!```&)O__SL`````00X(0H4"#05!@P-UPT'%
M#`0$`!````!P!```+YO__P0`````````*````(0$```@F___6@````!!#@A"
MA0(-!4.#!88$AP,"4,-!QD''0<4,!`0<````L`0``%2;__\%`````$$."$*%
M`@T%0<4,!`0`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#_____`````/____\```````````$````!`````0```*T"
M```!````O`(```$```#(`@```0```-,"```!````W0(```$```#K`@```0``
M`/@"```!````1P,```\```"T!```#````*R4!`@-````/,H$"/7^_V^,@00(
M!0```#2*!`@&````Y(($"`H```!,!@``"P```!`````5``````````,````H
M,04(`@```(@"```4````$0```!<````DD@0($0````R2!`@2````&````!,`
M```(````_O__;VR1!`C___]O`@```/#__V^`D`0(````````````````````
M`````````````````````````````````````````````````!0P!0@`````
M`````/*4!`@"E00($I4$""*5!`@RE00(0I4$"%*5!`ABE00(<I4$"(*5!`B2
ME00(HI4$"+*5!`C"E00(TI4$".*5!`CRE00(`I8$"!*6!`@BE@0(,I8$"$*6
M!`A2E@0(8I8$"'*6!`B"E@0(DI8$"**6!`BRE@0(PI8$"-*6!`CBE@0(\I8$
M"`*7!`@2EP0((I<$"#*7!`A"EP0(4I<$"&*7!`AREP0(@I<$")*7!`BBEP0(
MLI<$",*7!`C2EP0(XI<$"/*7!`@"F`0($I@$""*8!`@RF`0(0I@$"%*8!`AB
MF`0(<I@$"(*8!`B2F`0(HI@$"+*8!`C"F`0(TI@$".*8!`CRF`0(`ID$"!*9
M!`@BF00(,ID$"$*9!`A2F00(8ID$"'*9!`B"F00(DID$"**9!`BRF00(PID$
M"-*9!`CBF00(\ID$"`````#_____",T$".E;``!'0T,Z("A'3E4I(#0N-2XP
M(#(P,3`P-S$V("A2960@2&%T(#0N-2XP+3,I`$=#0SH@*$=.52D@-"XU+C$@
M,C`Q,#`X,3(@*%)E9"!(870@-"XU+C$M,2D``"YS:'-T<G1A8@`N:6YT97)P
M`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H
M7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YD>6YA
M;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````
M````````````````````````````````````````````"P````$````"````
M-($$"#0!```3```````````````!`````````!,````'`````@```$B!!`A(
M`0``(```````````````!``````````A````!P````(```!H@00(:`$``"0`
M``````````````0`````````-````/;__V\"````C($$"(P!``!8`0``!0``
M```````$````!````#X````+`````@```.2"!`CD`@``4`<```8````!````
M!````!````!&`````P````(````TB@0(-`H``$P&``````````````$`````
M````3@```/___V\"````@)`$"(`0``#J````!0`````````"`````@```%L`
M``#^__]O`@```&R1!`AL$0``H`````8````"````!`````````!J````"0``
M``(````,D@0(#!(``!@````%``````````0````(````<P````D````"````
M))($""02``"(`@``!0````P````$````"````'P````!````!@```*R4!`BL
M%```,```````````````!`````````!W`````0````8```#<E`0(W!0``"`%
M``````````````0````$````@@````$````&`````)H$"``:```\,```````
M```````0`````````(@````!````!@```#S*!`@\2@``'```````````````
M!`````````".`````0````(```!@R@0(8$H``*I>`````````````"``````
M````E@````$````"````#"D%"`RI``#L```````````````$`````````*0`
M```!`````@```/@I!0CXJ0``T`0`````````````!`````````"N`````0``
M``,`````,`4(`+````@```````````````0`````````M0````$````#````
M"#`%"`BP```(```````````````$`````````+P````!`````P```!`P!0@0
ML```!```````````````!`````````#!````!@````,````4,`4(%+```!`!
M```&``````````0````(````R@````$````#````)#$%""2Q```$````````
M```````$````!````,\````!`````P```"@Q!0@HL0``4`$`````````````
M!`````0```#8`````0````,```!X,@4(>+(``!````````````````0`````
M````W@````@````#````H#(%"(BR``!`$``````````````@`````````.,`
M```!````,`````````"(L@``6````````````````0````$````!`````P``
A````````````X+(``.P```````````````$`````````
